@@ -37,8 +37,8 @@ rautologistic = function(X, A, theta)
 {
     if (missing(X) || ! is.matrix(X) || ! is.numeric(X))
         stop("You must supply a suitable design matrix.")
-    if (missing(A) || ! is.matrix(A) || ! isSymmetric(A) || ! is.numeric(A))
-        stop("You must supply a numeric and symmetric adjacency matrix.")
+    if (missing(A) || ! is.matrix(A) || ! isSymmetric(A) || ! all(A == 0 | A == 1))
+        stop("You must supply a symmetric binary adjacency matrix.")
     diag(A) = 0
     if (nrow(X) != nrow(A))
         stop("The supplied design matrix and adjacency matrix are not conformable.")
@@ -627,8 +627,8 @@ autologistic = function(formula, data, A, method = c("PL", "Bayes"), model = TRU
     cl = match.call()   
     if (missing(formula))
         stop("You must supply a formula.")
-    if (missing(A) || ! is.matrix(A) || ! isSymmetric(A) || ! is.numeric(A))
-        stop("You must supply a numeric and symmetric adjacency matrix.")
+    if (missing(A) || ! is.matrix(A) || ! isSymmetric(A) || ! all(A == 0 | A == 1))
+        stop("You must supply a symmetric binary adjacency matrix.")
     diag(A) = 0
     mf = match.call(expand.dots = FALSE)
     m = match(c("formula", "data"), names(mf), 0)
@@ -638,7 +638,7 @@ autologistic = function(formula, data, A, method = c("PL", "Bayes"), model = TRU
     mt = attr(mf, "terms")
     Z = model.response(mf, "numeric")
     X = model.matrix(mt, mf)
-    if (! is.vector(Z) || ! (Z == 0 || Z == 1))
+    if (! is.vector(Z) || ! all(Z == 0 | Z == 1))
         stop("The response must be a binary vector.")
     if (sum(c(nrow(X), nrow(A)) != length(Z)) > 0)
         stop("The supplied response vector/design matrix/adjacency matrix are not conformable.")
